@@ -1,7 +1,7 @@
 /* testvarnames.cpp
    Test variable and function names, lists of variables on one line, etc.
 
-   Copyright (C) 2008, 2009, 2010, 2011, 2012 Free Software Foundation, Inc.
+   Copyright (C) 2008-2012 Free Software Foundation, Inc.
 
    Author: Eric M. Ludlam <eric@siege-engine.com>
 
@@ -31,7 +31,7 @@ struct independent var_indep_struct;
 struct {
   int unnamed_1;
   int unnamed_2;
-} var_unamed_struct;
+} var_unnamed_struct;
 
 struct {
   int unnamed_3;
@@ -59,12 +59,12 @@ struct inline2struct in_var2;
 int test_1(int var_arg1) {
 
   var_// -1-
-    ; // #1# ("var_arg1" "var_indep_struct" "var_n_2" "var_n_3" "var_named_struct" "var_un_2" "var_un_3" "var_unamed_struct")
+    ; // #1# ("var_arg1" "var_indep_struct" "var_n_2" "var_n_3" "var_named_struct" "var_un_2" "var_un_3" "var_unnamed_struct")
 
   var_indep_struct.// -2-
     ; // #2# ( "indep_1" "indep_2" )
 
-  var_unamed_struct.// -3-
+  var_unnamed_struct.// -3-
     ; // #3# ( "unnamed_1" "unnamed_2" )
 
   var_named_struct.// -4-
@@ -88,6 +88,3 @@ int test_1(int var_arg1) {
   in_var2.// -11-
     ; // #11# ( "named_3" "named_4")
 }
-
-/* arch-tag: ca9f23e9-0c66-4a5e-b233-3fdc841d3a63
-   (do not change this comment) */
